summaryrefslogtreecommitdiffstats
path: root/kaddressbook/kaddressbookview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/kaddressbookview.cpp')
-rw-r--r--kaddressbook/kaddressbookview.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kaddressbook/kaddressbookview.cpp b/kaddressbook/kaddressbookview.cpp
index 28fd81af..2059fbb3 100644
--- a/kaddressbook/kaddressbookview.cpp
+++ b/kaddressbook/kaddressbookview.cpp
@@ -79,7 +79,7 @@ TQString KAddressBookView::selectedEmails()
TQStringList::ConstIterator it;
for ( it = uidList.begin(); it != uidList.end(); ++it ) {
- addr = mCore->addressBook()->findByUid( *it );
+ addr = mCore->addressBook()->tqfindByUid( *it );
if ( !addr.isEmpty() ) {
TQString m = TQString::null;
@@ -121,12 +121,12 @@ KABC::Addressee::List KAddressBookView::addressees()
void KAddressBookView::initGUI()
{
- // Create the layout
- TQVBoxLayout *layout = new TQVBoxLayout( this );
+ // Create the tqlayout
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
// Add the view widget
mViewWidget = new TQWidget( this );
- layout->addWidget( mViewWidget );
+ tqlayout->addWidget( mViewWidget );
}
KABC::Field::List KAddressBookView::fields() const